@@ -16,9 +16,17 @@
 This module provides a DocTestSuite contructor for converting doctest
 tests to unit tests.
 
-$Id: doctestunit.py 104880 2009-10-07 17:53:44Z sidnei $
+$Id: doctestunit.py 106860 2009-12-22 09:22:05Z mgedmin $
 """
 
+import warnings
+warnings.warn('zope.testing.doctestunit is deprecated in favour of '
+              'the Python standard library doctest module', DeprecationWarning,
+              stacklevel=2)
+
+from doctest import DocFileSuite, DocTestSuite
+from doctest import debug_src, debug
+
 def pprint():
     from pprint import PrettyPrinter
     def pprint(ob, **opts):
